import {
  geoNaturalEarth1,
  geoPath,
  geoGraticule,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';
import { useMemo, useContext } from 'react';
import Tippy from 'tippy';

// import { tooltipContext } from "../useTooltip";

// const { tooltip, setTooltip } = useContext(tooltipContext);

const projection = geoNaturalEarth1();
const path = geoPath(projection);
const graticule = geoGraticule();
const colorScale = scaleOrdinal(schemeCategory10);

export const Marks = ({
  worldAtlas: { land, interiors },
  data,
  sizeScale,
  sizeValue,
}) => (
  <g className="marks">
    {useMemo(
      () => (
        <>
          <path
            className="sphere"
            d={path({ type: 'Sphere' })}
          />
          <path
            className="graticules"
            d={path(graticule())}
          />
          {land.features.map((feature) => (
            <path className="land" d={path(feature)} />
          ))}
          <path className="interiors" d={path(interiors)} />
        </>
      ),
      [path, graticule, land, interiors]
    )}
    {data.map((d) => {
      const [x, y] = projection(d.coords);

      return (
        <Tippy
          disabled={false}
          content={
            <span>
              <strong>
                {
                  d.name + ' ' + d.occupation + ' ' + d.birthyear + ' ' + d.bplace_name + ' ' + d.bplace_country
                }
              </strong>
            </span>
          }
        >
          <g>
            {' '}
            <circle
              cx={x}
              cy={y}
              fill={colorScale(d.occupation)}
              r={sizeScale(sizeValue(d))}
              title={d.name + ' ' + d.occupation}
              
            />
          </g>
        </Tippy>
      );
    })}
  </g>
);
